==> healthrian_ble_support_for_wearecg12-1.1.33.tar.gz: example/lib/ble/view/ble_page.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_mobx/flutter_mobx.dart';
import 'package:healthrian_ble_support_for_wearecg12/'
    'healthrian_ble_support_for_wearecg12.dart';
import 'package:lzma/lzma.dart';

class BlePage extends StatefulWidget {
  const BlePage({super.key});

  @override
  State<BlePage> createState() => _BlePageState();
}

class _BlePageState extends State<BlePage> {
  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return SafeArea(
      child: Scaffold(
        /// express a received packet which contains ecg signal
        body: Column(
          children: [
            Observer(
              key: UniqueKey(),
              builder: (context) {
                return StreamBuilder(
                  stream: BLEManager().ble.streams.rawEcg,
                  builder: (context, snapshot) {
                    if (!snapshot.hasData) return const SizedBox();
                    final data = snapshot.data ?? [];
                    final cData = lzma.encode(data);
                    final rData = [
                      for (var i = 0; i < 6; i++) data[i],
                      for (var j = 6; j < 30; j++)
                        // if (j % 3 == 1)
                        for (var i = 0; i < 9; i++) data[j + i * 24],
                    ];
                    final rcData = lzma.encode(rData);
                    return Text(
                      '${data.length}\n'
                      '${cData.length}\n'
                      '${rData.length}\n'
                      '${rcData.length}\n',
                    );
                  },
                );
              },
            ),
          ],
        ),

        /// control panel
        floatingActionButton: Column(
          mainAxisAlignment: MainAxisAlignment.end,
          children: [
            // FloatingActionButton(
            //   onPressed: () async {
            //     final d = await BLEManager().ble.getDevices();
            //     print(d.connected);
            //     print(d.scaned);
            //   },
            //   child: const Icon(Icons.bluetooth),
            // ),
            FloatingActionButton(
              onPressed: () async {
                await BLEManager().connectDevice();
                await BLEManager().registerCharacteristics();
              },
              child: const Icon(Icons.bluetooth),
            ),
            FloatingActionButton(
              onPressed: BLEManager().disconnectDevice,
              child: const Icon(Icons.bluetooth_disabled),
            ),
            FloatingActionButton(
              onPressed: BLEManager().startMeasurement,
              child: const Icon(Icons.play_arrow),
            ),
            FloatingActionButton(
              onPressed: BLEManager().pauseMeasurement,
              child: const Icon(Icons.pause),
            ),
            FloatingActionButton(
              onPressed: ()async{
                await BLEManager().stopMeasurement();
                BLEManager().ecg.initStream();
              },
              child: const Icon(Icons.stop),
            ),
          ],
        ),
      ),
    );
  }
}

==> healthrian_ble_support_for_wearecg12-1.1.38.tar.gz: example/lib/ble/view/ble_page.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_mobx/flutter_mobx.dart';
import 'package:healthrian_ble_support_for_wearecg12/'
    'healthrian_ble_support_for_wearecg12.dart';
import 'package:lzma/lzma.dart';

class BlePage extends StatefulWidget {
  const BlePage({super.key});

  @override
  State<BlePage> createState() => _BlePageState();
}

class _BlePageState extends State<BlePage> {
  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return SafeArea(
      child: Scaffold(
        /// express a received packet which contains ecg signal
        body: Column(
          children: [
            Observer(
              key: UniqueKey(),
              builder: (context) {
                return StreamBuilder(
                  stream: BLEManager().streams.rawEcg,
                  builder: (context, snapshot) {
                    if (!snapshot.hasData) return const SizedBox();
                    final data = snapshot.data ?? [];
                    final cData = lzma.encode(data);
                    final rData = [
                      for (var i = 0; i < 6; i++) data[i],
                      for (var j = 6; j < 30; j++)
                        // if (j % 3 == 1)
                        for (var i = 0; i < 9; i++) data[j + i * 24],
                    ];
                    final rcData = lzma.encode(rData);
                    return Text(
                      '${data.length}\n'
                      '${cData.length}\n'
                      '${rData.length}\n'
                      '${rcData.length}\n',
                    );
                  },
                );
              },
            ),
          ],
        ),

        /// control panel
        floatingActionButton: Column(
          mainAxisAlignment: MainAxisAlignment.end,
          children: [
            // FloatingActionButton(
            //   onPressed: () async {
            //     final d = await BLEManager().ble.getDevices();
            //     print(d.connected);
            //     print(d.scaned);
            //   },
            //   child: const Icon(Icons.bluetooth),
            // ),
            FloatingActionButton(
              onPressed: () async {
                await BLEManager().connectDevice();
                await BLEManager().registerCharacteristics();
              },
              child: const Icon(Icons.bluetooth),
            ),
            FloatingActionButton(
              onPressed: BLEManager().disconnectDevice,
              child: const Icon(Icons.bluetooth_disabled),
            ),
            FloatingActionButton(
              onPressed: BLEManager().startMeasurement,
              child: const Icon(Icons.play_arrow),
            ),
            FloatingActionButton(
              onPressed: BLEManager().pauseMeasurement,
              child: const Icon(Icons.pause),
            ),
            FloatingActionButton(
              onPressed: ()async{
                await BLEManager().stopMeasurement();
                // BLEManager().ecg.initStream();
              },
              child: const Icon(Icons.stop),
            ),
          ],
        ),
      ),
    );
  }
}
